@@ -39,6 +39,9 @@ build_site <- function(...) {
     "v2.1.3" = {
       build_site_offline_1(...)
     },
+    "v2.2.0" = {
+      build_site_offline_1(...)
+    },
     "future" = {
       message(
         "pkgdown.offline support for this new pkgdown version is unknown.\n",
@@ -70,6 +73,8 @@ get_version_category <- function(version) {
     return("v2.1.2")
   } else if (compare_version(version, "==", "2.1.3")) {
     return("v2.1.3")
+  } else if (compare_version(version, "==", "2.2.0")) {
+    return("v2.2.0")
   } else {
     return("future")
   }
